@@ -885,18 +885,24 @@ class DataflowHostManagement(OpenApiObject):
 
     _TYPES = {
         'host_name': {'type': str},
+        'nic_rx_buffer': {'type': int},
+        'nic_tx_buffer': {'type': int},
+        'nic_speed': {'type': int},
         'management_address': {'type': str},
         'nic_name': {'type': str},
     } # type: Dict[str, str]
 
-    _REQUIRED = ('host_name', 'management_address', 'nic_name') # type: tuple(str)
+    _REQUIRED = ('host_name',) # type: tuple(str)
 
     _DEFAULTS= {} # type: Dict[str, Union(type)]
 
-    def __init__(self, parent=None, host_name=None, management_address=None, nic_name=None):
+    def __init__(self, parent=None, host_name=None, nic_rx_buffer=None, nic_tx_buffer=None, nic_speed=None, management_address=None, nic_name=None):
         super(DataflowHostManagement, self).__init__()
         self._parent = parent
         self._set_property('host_name', host_name)
+        self._set_property('nic_rx_buffer', nic_rx_buffer)
+        self._set_property('nic_tx_buffer', nic_tx_buffer)
+        self._set_property('nic_speed', nic_speed)
         self._set_property('management_address', management_address)
         self._set_property('nic_name', nic_name)
 
@@ -921,6 +927,69 @@ class DataflowHostManagement(OpenApiObject):
         """
         self._set_property('host_name', value)
 
+    @property
+    def nic_rx_buffer(self):
+        # type: () -> int
+        """nic_rx_buffer getter
+
+        RX buffer size in bytes
+
+        Returns: int
+        """
+        return self._get_property('nic_rx_buffer')
+
+    @nic_rx_buffer.setter
+    def nic_rx_buffer(self, value):
+        """nic_rx_buffer setter
+
+        RX buffer size in bytes
+
+        value: int
+        """
+        self._set_property('nic_rx_buffer', value)
+
+    @property
+    def nic_tx_buffer(self):
+        # type: () -> int
+        """nic_tx_buffer getter
+
+        TX buffer size in bytes
+
+        Returns: int
+        """
+        return self._get_property('nic_tx_buffer')
+
+    @nic_tx_buffer.setter
+    def nic_tx_buffer(self, value):
+        """nic_tx_buffer setter
+
+        TX buffer size in bytes
+
+        value: int
+        """
+        self._set_property('nic_tx_buffer', value)
+
+    @property
+    def nic_speed(self):
+        # type: () -> int
+        """nic_speed getter
+
+        configured link speed Mbps (e.g. 100000 for 100G)
+
+        Returns: int
+        """
+        return self._get_property('nic_speed')
+
+    @nic_speed.setter
+    def nic_speed(self, value):
+        """nic_speed setter
+
+        configured link speed Mbps (e.g. 100000 for 100G)
+
+        value: int
+        """
+        self._set_property('nic_speed', value)
+
     @property
     def management_address(self):
         # type: () -> str
@@ -990,27 +1059,27 @@ class DataflowHostManagementIter(OpenApiIter):
         # type: () -> DataflowHostManagement
         return self._next()
 
-    def hostmanagement(self, host_name=None, management_address=None, nic_name=None):
-        # type: (str,str,str) -> DataflowHostManagementIter
+    def hostmanagement(self, host_name=None, nic_rx_buffer=None, nic_tx_buffer=None, nic_speed=None, management_address=None, nic_name=None):
+        # type: (str,int,int,int,str,str) -> DataflowHostManagementIter
         """Factory method that creates an instance of the DataflowHostManagement class
 
         auxillary host information needed to run dataflow experiments
 
         Returns: DataflowHostManagementIter
         """
-        item = DataflowHostManagement(parent=self._parent, host_name=host_name, management_address=management_address, nic_name=nic_name)
+        item = DataflowHostManagement(parent=self._parent, host_name=host_name, nic_rx_buffer=nic_rx_buffer, nic_tx_buffer=nic_tx_buffer, nic_speed=nic_speed, management_address=management_address, nic_name=nic_name)
         self._add(item)
         return self
 
-    def add(self, host_name=None, management_address=None, nic_name=None):
-        # type: (str,str,str) -> DataflowHostManagement
+    def add(self, host_name=None, nic_rx_buffer=None, nic_tx_buffer=None, nic_speed=None, management_address=None, nic_name=None):
+        # type: (str,int,int,int,str,str) -> DataflowHostManagement
         """Add method that creates and returns an instance of the DataflowHostManagement class
 
         auxillary host information needed to run dataflow experiments
 
         Returns: DataflowHostManagement
         """
-        item = DataflowHostManagement(parent=self._parent, host_name=host_name, management_address=management_address, nic_name=nic_name)
+        item = DataflowHostManagement(parent=self._parent, host_name=host_name, nic_rx_buffer=nic_rx_buffer, nic_tx_buffer=nic_tx_buffer, nic_speed=nic_speed, management_address=management_address, nic_name=nic_name)
         self._add(item)
         return item
 
@@ -1029,6 +1098,7 @@ class DataflowWorkloadItem(OpenApiObject):
                 'loop',
                 'compute',
                 'broadcast',
+                'all_to_all',
             ],
         },
         'scatter': {'type': 'DataflowScatterWorkload'},
@@ -1050,6 +1120,7 @@ class DataflowWorkloadItem(OpenApiObject):
     LOOP = 'loop' # type: str
     COMPUTE = 'compute' # type: str
     BROADCAST = 'broadcast' # type: str
+    ALL_TO_ALL = 'all_to_all' # type: str
 
     def __init__(self, parent=None, choice=None, name=None):
         super(DataflowWorkloadItem, self).__init__()
@@ -1126,6 +1197,17 @@ class DataflowWorkloadItem(OpenApiObject):
         """
         return self._get_property('broadcast', DataflowBroadcastWorkload, self, 'broadcast')
 
+    @property
+    def all_to_all(self):
+        # type: () -> DataflowAlltoallWorkload
+        """Factory property that returns an instance of the DataflowAlltoallWorkload class
+
+        creates full-mesh flows between all nodes
+
+        Returns: DataflowAlltoallWorkload
+        """
+        return self._get_property('all_to_all', DataflowAlltoallWorkload, self, 'all_to_all')
+
     @property
     def name(self):
         # type: () -> str
@@ -1149,12 +1231,12 @@ class DataflowWorkloadItem(OpenApiObject):
 
     @property
     def choice(self):
-        # type: () -> Union[Literal["all_reduce"], Literal["broadcast"], Literal["compute"], Literal["gather"], Literal["loop"], Literal["scatter"]]
+        # type: () -> Union[Literal["all_reduce"], Literal["all_to_all"], Literal["broadcast"], Literal["compute"], Literal["gather"], Literal["loop"], Literal["scatter"]]
         """choice getter
 
         The type of workflow item
 
-        Returns: Union[Literal["all_reduce"], Literal["broadcast"], Literal["compute"], Literal["gather"], Literal["loop"], Literal["scatter"]]
+        Returns: Union[Literal["all_reduce"], Literal["all_to_all"], Literal["broadcast"], Literal["compute"], Literal["gather"], Literal["loop"], Literal["scatter"]]
         """
         return self._get_property('choice')
 
@@ -1164,21 +1246,10 @@ class DataflowWorkloadItem(OpenApiObject):
 
         The type of workflow item
 
-        value: Union[Literal["all_reduce"], Literal["broadcast"], Literal["compute"], Literal["gather"], Literal["loop"], Literal["scatter"]]
+        value: Union[Literal["all_reduce"], Literal["all_to_all"], Literal["broadcast"], Literal["compute"], Literal["gather"], Literal["loop"], Literal["scatter"]]
         """
         self._set_property('choice', value)
 
-    @property
-    def all_to_all(self):
-        # type: () -> DataflowAlltoallWorkload
-        """all_to_all getter
-
-        creates full-mesh flows between all nodescreates full-mesh flows between all nodes
-
-        Returns: DataflowAlltoallWorkload
-        """
-        return self._get_property('all_to_all', DataflowAlltoallWorkload)
-
 
 class DataflowScatterWorkload(OpenApiObject):
     __slots__ = ('_parent')
@@ -1421,7 +1492,7 @@ class DataflowWorkloadItemIter(OpenApiIter):
         self._choice = choice
 
     def __getitem__(self, key):
-        # type: (str) -> Union[DataflowAllReduceWorkload, DataflowBroadcastWorkload, DataflowComputeWorkload, DataflowGatherWorkload, DataflowLoopWorkload, DataflowScatterWorkload, DataflowWorkloadItem]
+        # type: (str) -> Union[DataflowAllReduceWorkload, DataflowAlltoallWorkload, DataflowBroadcastWorkload, DataflowComputeWorkload, DataflowGatherWorkload, DataflowLoopWorkload, DataflowScatterWorkload, DataflowWorkloadItem]
         return self._getitem(key)
 
     def __iter__(self):
@@ -1859,6 +1930,7 @@ class DataflowFlowProfile(OpenApiObject):
                 'udp',
             ],
         },
+        'ip': {'type': 'DataflowFlowProfileIp'},
         'tcp': {'type': 'DataflowFlowProfileTcp'},
         'udp': {'type': 'DataflowFlowProfileUdp'},
     } # type: Dict[str, str]
@@ -1975,6 +2047,17 @@ class DataflowFlowProfile(OpenApiObject):
         """
         self._set_property('l4_protocol_choice', value)
 
+    @property
+    def ip(self):
+        # type: () -> DataflowFlowProfileIp
+        """ip getter
+
+        
+
+        Returns: DataflowFlowProfileIp
+        """
+        return self._get_property('ip', DataflowFlowProfileIp)
+
     @property
     def tcp(self):
         # type: () -> DataflowFlowProfileTcp
@@ -2038,6 +2121,44 @@ class DataflowFlowProfileEthernet(OpenApiObject):
         self._set_property('mtu', value)
 
 
+class DataflowFlowProfileIp(OpenApiObject):
+    __slots__ = ('_parent')
+
+    _TYPES = {
+        'dscp': {'type': int},
+    } # type: Dict[str, str]
+
+    _REQUIRED= () # type: tuple(str)
+
+    _DEFAULTS= {} # type: Dict[str, Union(type)]
+
+    def __init__(self, parent=None, dscp=None):
+        super(DataflowFlowProfileIp, self).__init__()
+        self._parent = parent
+        self._set_property('dscp', dscp)
+
+    @property
+    def dscp(self):
+        # type: () -> int
+        """dscp getter
+
+        differentiated services code point
+
+        Returns: int
+        """
+        return self._get_property('dscp')
+
+    @dscp.setter
+    def dscp(self, value):
+        """dscp setter
+
+        differentiated services code point
+
+        value: int
+        """
+        self._set_property('dscp', value)
+
+
 class DataflowFlowProfileTcp(OpenApiObject):
     __slots__ = ('_parent')
 
@@ -2054,6 +2175,12 @@ class DataflowFlowProfileTcp(OpenApiObject):
         'initcwnd': {'type': int},
         'send_buf': {'type': int},
         'receive_buf': {'type': int},
+        'delayed_ack': {'type': int},
+        'selective_ack': {'type': bool},
+        'min_rto': {'type': int},
+        'mss': {'type': int},
+        'ecn': {'type': bool},
+        'enable_timestamp': {'type': bool},
         'destination_port': {'type': 'L4PortRange'},
         'source_port': {'type': 'L4PortRange'},
     } # type: Dict[str, str]
@@ -2062,6 +2189,7 @@ class DataflowFlowProfileTcp(OpenApiObject):
 
     _DEFAULTS = {
         'congestion_algorithm': 'cubic',
+        'mss': 1500,
     } # type: Dict[str, Union(type)]
 
     BBR = 'bbr' # type: str
@@ -2069,13 +2197,19 @@ class DataflowFlowProfileTcp(OpenApiObject):
     CUBIC = 'cubic' # type: str
     RENO = 'reno' # type: str
 
-    def __init__(self, parent=None, congestion_algorithm='cubic', initcwnd=None, send_buf=None, receive_buf=None):
+    def __init__(self, parent=None, congestion_algorithm='cubic', initcwnd=None, send_buf=None, receive_buf=None, delayed_ack=None, selective_ack=None, min_rto=None, mss=1500, ecn=None, enable_timestamp=None):
         super(DataflowFlowProfileTcp, self).__init__()
         self._parent = parent
         self._set_property('congestion_algorithm', congestion_algorithm)
         self._set_property('initcwnd', initcwnd)
         self._set_property('send_buf', send_buf)
         self._set_property('receive_buf', receive_buf)
+        self._set_property('delayed_ack', delayed_ack)
+        self._set_property('selective_ack', selective_ack)
+        self._set_property('min_rto', min_rto)
+        self._set_property('mss', mss)
+        self._set_property('ecn', ecn)
+        self._set_property('enable_timestamp', enable_timestamp)
 
     @property
     def congestion_algorithm(self):
@@ -2161,6 +2295,132 @@ class DataflowFlowProfileTcp(OpenApiObject):
         """
         self._set_property('receive_buf', value)
 
+    @property
+    def delayed_ack(self):
+        # type: () -> int
+        """delayed_ack getter
+
+        delayed acknowledgment
+
+        Returns: int
+        """
+        return self._get_property('delayed_ack')
+
+    @delayed_ack.setter
+    def delayed_ack(self, value):
+        """delayed_ack setter
+
+        delayed acknowledgment
+
+        value: int
+        """
+        self._set_property('delayed_ack', value)
+
+    @property
+    def selective_ack(self):
+        # type: () -> bool
+        """selective_ack getter
+
+        selective acknowledgment
+
+        Returns: bool
+        """
+        return self._get_property('selective_ack')
+
+    @selective_ack.setter
+    def selective_ack(self, value):
+        """selective_ack setter
+
+        selective acknowledgment
+
+        value: bool
+        """
+        self._set_property('selective_ack', value)
+
+    @property
+    def min_rto(self):
+        # type: () -> int
+        """min_rto getter
+
+        minimum retransmission timeout
+
+        Returns: int
+        """
+        return self._get_property('min_rto')
+
+    @min_rto.setter
+    def min_rto(self, value):
+        """min_rto setter
+
+        minimum retransmission timeout
+
+        value: int
+        """
+        self._set_property('min_rto', value)
+
+    @property
+    def mss(self):
+        # type: () -> int
+        """mss getter
+
+        Maximum Segment Size
+
+        Returns: int
+        """
+        return self._get_property('mss')
+
+    @mss.setter
+    def mss(self, value):
+        """mss setter
+
+        Maximum Segment Size
+
+        value: int
+        """
+        self._set_property('mss', value)
+
+    @property
+    def ecn(self):
+        # type: () -> bool
+        """ecn getter
+
+        early congestion notification
+
+        Returns: bool
+        """
+        return self._get_property('ecn')
+
+    @ecn.setter
+    def ecn(self, value):
+        """ecn setter
+
+        early congestion notification
+
+        value: bool
+        """
+        self._set_property('ecn', value)
+
+    @property
+    def enable_timestamp(self):
+        # type: () -> bool
+        """enable_timestamp getter
+
+        enable tcp timestamping
+
+        Returns: bool
+        """
+        return self._get_property('enable_timestamp')
+
+    @enable_timestamp.setter
+    def enable_timestamp(self, value):
+        """enable_timestamp setter
+
+        enable tcp timestamping
+
+        value: bool
+        """
+        self._set_property('enable_timestamp', value)
+
     @property
     def destination_port(self):
         # type: () -> L4PortRange
